bayespy.inference.vmp.nodes.gaussian.GaussianWishartDistribution.plates_from_parent
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartDistribution.plates_from_parent